==> openshift-model-operatorhub-6.9.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1/OLMConfigSpecFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class OLMConfigSpecFluent<A extends OLMConfigSpecFluent<A>> extends BaseFluent<A>{
  public OLMConfigSpecFluent() {
  }
  
  public OLMConfigSpecFluent(OLMConfigSpec instance) {
    this.copyInstance(instance);
  }
  private FeaturesBuilder features;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(OLMConfigSpec instance) {
    instance = (instance != null ? instance : new OLMConfigSpec());
  
    if (instance != null) {
        this.withFeatures(instance.getFeatures());
        this.withFeatures(instance.getFeatures());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public Features buildFeatures() {
    return this.features!=null ?this.features.build():null;
  }
  
  public A withFeatures(Features features) {
    _visitables.get("features").remove(this.features);
    if (features!=null){ this.features= new FeaturesBuilder(features); _visitables.get("features").add(this.features);} else { this.features = null; _visitables.get("features").remove(this.features); } return (A) this;
  }
  
  public boolean hasFeatures() {
    return this.features != null;
  }
  
  public A withNewFeatures(Boolean disableCopiedCSVs) {
    return (A)withFeatures(new Features(disableCopiedCSVs));
  }
  
  public FeaturesNested<A> withNewFeatures() {
    return new FeaturesNested(null);
  }
  
  public FeaturesNested<A> withNewFeaturesLike(Features item) {
    return new FeaturesNested(item);
  }
  
  public FeaturesNested<A> editFeatures() {
    return withNewFeaturesLike(java.util.Optional.ofNullable(buildFeatures()).orElse(null));
  }
  
  public FeaturesNested<A> editOrNewFeatures() {
    return withNewFeaturesLike(java.util.Optional.ofNullable(buildFeatures()).orElse(new FeaturesBuilder().build()));
  }
  
  public FeaturesNested<A> editOrNewFeaturesLike(Features item) {
    return withNewFeaturesLike(java.util.Optional.ofNullable(buildFeatures()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OLMConfigSpecFluent that = (OLMConfigSpecFluent) o;
    if (!java.util.Objects.equals(features, that.features)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(features,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (features != null) { sb.append("features:"); sb.append(features + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class FeaturesNested<N> extends FeaturesFluent<FeaturesNested<N>> implements Nested<N>{
    FeaturesNested(Features item) {
      this.builder = new FeaturesBuilder(this, item);
    }
    FeaturesBuilder builder;
    
    public N and() {
      return (N) OLMConfigSpecFluent.this.withFeatures(builder.build());
    }
    
    public N endFeatures() {
      return and();
    }
    
  
  }

}

==> openshift-model-operatorhub-6.9.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1/OLMConfigSpecFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class OLMConfigSpecFluent<A extends OLMConfigSpecFluent<A>> extends BaseFluent<A>{
  public OLMConfigSpecFluent() {
  }
  
  public OLMConfigSpecFluent(OLMConfigSpec instance) {
    this.copyInstance(instance);
  }
  private FeaturesBuilder features;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(OLMConfigSpec instance) {
    instance = (instance != null ? instance : new OLMConfigSpec());
    if (instance != null) {
          this.withFeatures(instance.getFeatures());
          this.withFeatures(instance.getFeatures());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public Features buildFeatures() {
    return this.features != null ? this.features.build() : null;
  }
  
  public A withFeatures(Features features) {
    this._visitables.remove(this.features);
    if (features != null) {
        this.features = new FeaturesBuilder(features);
        this._visitables.get("features").add(this.features);
    } else {
        this.features = null;
        this._visitables.get("features").remove(this.features);
    }
    return (A) this;
  }
  
  public boolean hasFeatures() {
    return this.features != null;
  }
  
  public A withNewFeatures(Boolean disableCopiedCSVs) {
    return (A)withFeatures(new Features(disableCopiedCSVs));
  }
  
  public FeaturesNested<A> withNewFeatures() {
    return new FeaturesNested(null);
  }
  
  public FeaturesNested<A> withNewFeaturesLike(Features item) {
    return new FeaturesNested(item);
  }
  
  public FeaturesNested<A> editFeatures() {
    return withNewFeaturesLike(java.util.Optional.ofNullable(buildFeatures()).orElse(null));
  }
  
  public FeaturesNested<A> editOrNewFeatures() {
    return withNewFeaturesLike(java.util.Optional.ofNullable(buildFeatures()).orElse(new FeaturesBuilder().build()));
  }
  
  public FeaturesNested<A> editOrNewFeaturesLike(Features item) {
    return withNewFeaturesLike(java.util.Optional.ofNullable(buildFeatures()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OLMConfigSpecFluent that = (OLMConfigSpecFluent) o;
    if (!java.util.Objects.equals(features, that.features)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(features,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (features != null) { sb.append("features:"); sb.append(features + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class FeaturesNested<N> extends FeaturesFluent<FeaturesNested<N>> implements Nested<N>{
    FeaturesNested(Features item) {
      this.builder = new FeaturesBuilder(this, item);
    }
    FeaturesBuilder builder;
    
    public N and() {
      return (N) OLMConfigSpecFluent.this.withFeatures(builder.build());
    }
    
    public N endFeatures() {
      return and();
    }
    
  
  }

}
